@@ -24,19 +24,21 @@
 
 #include "config.h"
 
+#include <string.h>
+
 #include "empathy-message.h"
+#include "empathy-enum-types.h"
 
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EMPATHY_TYPE_MESSAGE, EmpathyMessagePriv))
 
 typedef struct _EmpathyMessagePriv EmpathyMessagePriv;
 
 struct _EmpathyMessagePriv {
-	EmpathyMessageType     type;
-	EmpathyContact        *sender;
-	EmpathyContact        *receiver;
-	gchar                *body;
-	EmpathyTime            timestamp;
-
+	EmpathyMessageType  type;
+	EmpathyContact     *sender;
+	EmpathyContact     *receiver;
+	gchar              *body;
+	EmpathyTime         timestamp;
 };
 
 static void empathy_message_class_init (EmpathyMessageClass *class);
@@ -102,13 +104,12 @@ empathy_message_class_init (EmpathyMessageClass *class)
 
 	g_object_class_install_property (object_class,
 					 PROP_TYPE,
-					 g_param_spec_int ("type",
-							   "Message Type",
-							   "The type of message",
-							   EMPATHY_MESSAGE_TYPE_NORMAL,
-							   EMPATHY_MESSAGE_TYPE_LAST,
-							   EMPATHY_MESSAGE_TYPE_NORMAL,
-							   G_PARAM_READWRITE));
+					 g_param_spec_enum ("type",
+							    "Message Type",
+							    "The type of message",
+							    EMPATHY_TYPE_MESSAGE_TYPE,
+							    EMPATHY_MESSAGE_TYPE_NORMAL,
+							    G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
 					 PROP_SENDER,
 					 g_param_spec_object ("sender",
@@ -186,7 +187,7 @@ message_get_property (GObject    *object,
 
 	switch (param_id) {
 	case PROP_TYPE:
-		g_value_set_int (value, priv->type);
+		g_value_set_enum (value, priv->type);
 		break;
 	case PROP_SENDER:
 		g_value_set_object (value, priv->sender);
@@ -216,7 +217,7 @@ message_set_property (GObject      *object,
 	switch (param_id) {
 	case PROP_TYPE:
 		empathy_message_set_type (EMPATHY_MESSAGE (object),
-					 g_value_get_int (value));
+					  g_value_get_enum (value));
 		break;
 	case PROP_SENDER:
 		empathy_message_set_sender (EMPATHY_MESSAGE (object),
@@ -416,3 +417,37 @@ empathy_message_set_timestamp (EmpathyMessage *message,
 	g_object_notify (G_OBJECT (message), "timestamp");
 }
 
+EmpathyMessageType
+empathy_message_type_from_str (const gchar *type_str)
+{
+	if (strcmp (type_str, "normal") == 0) {
+		return EMPATHY_MESSAGE_TYPE_NORMAL;
+	}
+	if (strcmp (type_str, "action") == 0) {
+		return EMPATHY_MESSAGE_TYPE_ACTION;
+	}
+	else if (strcmp (type_str, "notice") == 0) {
+		return EMPATHY_MESSAGE_TYPE_NOTICE;
+	}
+	else if (strcmp (type_str, "auto-reply") == 0) {
+		return EMPATHY_MESSAGE_TYPE_AUTO_REPLY;
+	}
+
+	return EMPATHY_MESSAGE_TYPE_NORMAL;
+}
+
+const gchar *
+empathy_message_type_to_str (EmpathyMessageType type)
+{
+	switch (type) {
+	case EMPATHY_MESSAGE_TYPE_ACTION:
+		return "action";
+	case EMPATHY_MESSAGE_TYPE_NOTICE:
+		return "notice";
+	case EMPATHY_MESSAGE_TYPE_AUTO_REPLY:
+		return "auto-reply";
+	default:
+		return "normal";
+	}
+}
+
